#!/usr/bin/env python
# -*- coding: utf-8 -*-


"""
    Control GPIO relays on raspberry pi
"""

RUN = True
try:
    import RPi.GPIO as GPIO
    GPIO.setmode(GPIO.BOARD)
except ImportError:
    RUN = False

from vinisto.i18n import _

VERBS = [_(u'Yes'), _(u'No')]


class Gpio(object):
    """
        Turn on/off GPIOs
    """
    def __init__(self, caller):
        self.caller = caller
        self.triggers = {
            _(u'Turn off the lights'):
                [12, GPIO.OUT, 1],
            _(u'Turn on the lights'):
                [12, GPIO.OUT, 0],
            _(u'Is there any light on?'):
                [14, GPIO.IN, lambda x: self.caller.tts.say(
                    VERBS[x])]
        }

    def callback(self, text):
        """
             cb
        """
        if not RUN:
            return

        text = text.lower()
        for trigger, data in self.triggers.items():
            if trigger in text:
                GPIO.setup(data[0], data[1])
                if data[1] == GPIO.OUT:
                    GPIO.output(data[0], data[2])
                else:
                    data[2](GPIO.input(data[0]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-


"""
    InfraRed
"""


from vinisto.i18n import _
import subprocess


class Repeat(object):
    """
        InfraRed module
        ---------------

        You need to have lirc configured.
        Then, associate:
            {
                'trigger': [ remote_control_name, press_key ]
            }
    """
    def __init__(self, caller):
        self.caller = caller
        self.triggers = {
            _(u'put the lights red'): ["light_control", "red"],
            _(u'turn the ac off'): ["ac_control", "key_0"],
        }

    def callback(self, text):
        """
            callback
        """
        text = text.lower()
        for trigger, data in self.triggers.items():
            if trigger in text:
                subprocess.Popen(["irsend", "SEND_ONCE", data[0], data[1]])



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import gettext

from vinisto import __PATH__, __APP_NAME__

LOCALE_DIR = os.path.join(__PATH__, 'i18n')

gettext.bind_textdomain_codeset(__APP_NAME__, "UTF-8")
language = gettext.translation(__APP_NAME__, LOCALE_DIR, fallback=False)

_ = language.ugettext



#!/usr/bin/env python
# -*- coding: utf-8 -*-


from __future__ import unicode_literals
from datetime import datetime
from vinisto.i18n import _


"""
    Time plugin.
    Speaks the time in spanish.
"""


class Time(object):
    """
        Simple plugin example
    """
    def __init__(self, caller):
        self.caller = caller
        self.trigger = [_(u'what time is it?'), _(u'It\'s {}')]

    def callback(self, text):
        """
             cb
        """
        trigger, response = self.trigger
        text = text.lower()

        if trigger in text:
            date_ = datetime.now().strftime(" %H %M %p").replace(" 0", " ")
            self.caller.tts.say(response.format(date_))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Google STT plugin
"""

import speech_recognition as sr
import logging

logging.basicConfig(loglevel=logging.INFO)
LOG = logging.getLogger(__name__)


class GoogleSTT(object):
    """
        Google Speech recognition
    """
    def __init__(self, language, rate, key):
        self.language = language
        self.rate = rate
        self.chunk = rate / 2
        self.key = key

    def get_audio(self):
        """
            Return recognized text
        """
        rrec = sr.Recognizer('es-ES', self.key)
        mic = sr.Microphone()
        mic.RATE = self.rate
        mic.CHUNK = self.chunk
        with mic as source:
            LOG.info("Mic waiting")
            rrec.adjust_for_ambient_noise(source)
            return rrec.recognize(rrec.listen(source))

    @property
    def text(self):
        """
            Waits for text to be recognized, then yields it
        """
        while True:
            try:
                audio = self.get_audio()
                LOG.info("Recognized: %s", audio)
                yield audio.lower()
            except LookupError:
                pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
    Google TTS plugin
"""

from tempfile import NamedTemporaryFile
from gtts import gTTS
import pygame


class GoogleTTS(object):
    """
        Google TTS
    """
    def __init__(self, language):
        self.language = language

    def say(self, text):
        """
            Play text with stt + mplayer
        """
        with NamedTemporaryFile(delete=False) as file_:
            gTTS(text=text, lang=self.language).write_to_fp(file_)

            pygame.mixer.init(frequency=36000)
            pygame.mixer.music.load(file_.name)
            pygame.mixer.music.play()

            while pygame.mixer.music.get_busy():
                pygame.time.Clock().tick(1)

            pygame.time.Clock().tick(10)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
    Vinisto
"""

from setuptools import setup, find_packages


with open('docs/Readme.rst') as readme_file:
    README = readme_file.read()

with open('docs/History.rst') as history_file:
    HISTORY = history_file.read().replace('.. :changelog:', '')

setup(
    name='vinisto',
    version='0.1.5',
    description="""
        Vinisto - a simple-minded home butler
    """,
    long_description=README + '\n\n' + HISTORY,
    author="David Francos Cuartero",
    author_email='me@davidfrancos.net',
    url='https://github.com/XayOn/vinisto',
    packages=find_packages(exclude=["tests", "docs"]),
    package_dir={'vinisto':
                 'vinisto'},
    include_package_data=True,
    install_requires=[
        'gtts',
        'speechrecognition',
        #'pygame'
    ],
    license="BSD",
    zip_safe=False,
    keywords='vinisto',
    entry_points={
        'console_scripts': [
            'vinisto = vinisto.main:main',
        ],
    },
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    test_suite='tests'
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-


from vinisto.i18n import _


"""
    Repeat
"""


class Repeat(object):
    """
        Repeats
    """
    def __init__(self, caller):
        self.caller = caller
        self.trigger = _('repeat')

    def callback(self, text):
        """
             cb
        """
        text = text.lower()
        if self.trigger in text:
            self.caller.tts.say(text.replace(self.trigger, ''))
